@@ -21,4 +21,4 @@
 
 prefix="/usr/local"
 sysconfdir="/etc"
-cupsserverbindir=""
+cupsserverbindir="/usr/local/libexec/cups"
